Compute immune tracking variables as a function of host age and exposure
Wda.delta.RdCompute immune tracking variables as a function of host age and exposure
Usage
# S3 method for class 'delta'
Wda(a, FoI_a, bday = 0, hhat = 1, par = par_Wda_delta())Arguments
- a
age of a host cohort
- FoI_a
a cohort trace function
- bday
cohort birthday
- hhat
overrides the value of hbar in par
- par
parameters in a list
Value
a numeric vector of length(a)