Compute the MLE for parasite counts data
counts_MLE.RdCompute the MLE for parasite counts data
Arguments
- alpha
the ages of infection
- counts
the counts
- inits
the initial guesses for the parameters
- F_b
a function to constrain the upper bound for fitting for Fmu
- F_Sa
a function to constrain the slope for fitting for Fmu
- q
the sampling volume (in \(\log_{10} microliters\))
- bvm
the blood volume (in \(\log_{10} microliters\))
- SANN
if true, then use simulated annealing