Skip to contents

This function computes the derivatives for the queuing model SquIP, in a form that can be used by deSolve::ode.

It also computes the derivatives for the hybrid variables \(m_1\) and \(m_2\)

Usage

dSquIP(a, y, pars, F_a)

Arguments

a

the host age

y

a vector of state variables

pars

the parameters

F_a

a trace function

Value

the derivatives as a list