Skip to contents

This computes the derivatives for the queuing model SquIP. It also computes the hybrid variables \(I, m_1\) and \(m_2\)

Usage

dSquIPz(a, y, pars, F_a, Z)

Arguments

a

the host age

y

a vector of state variables

pars

the parameters

F_a

a trace function

Z

the MoE matrix

Value

the derivatives as a list

See also

SquIP & solve_SquIP

This function computes the derivatives in a form that can be used by deSolve::ode.

solveMMinfty