Compute the log likelihood for a set of parasites counts data
llik_counts_sz.RdCompute the log likelihood for a set of parasites counts data
Arguments
- prms
A set of parameters to be fitted
- sz
the size parameter
- alpha
the AoI for the observations
- counts
the counts
- par_Fmu
an object to dispatch Fmu
- par_O
an object to dispath d_Omega
- F_b
a function to constrain the upper bound for fitting for Fmu
- F_Sa
a function to constrain the slope for fitting for Fmu
- q
the sampling volume (in \(\log_{10} microliters\))
- bvm
the blood volume (in \(\log_{10} microliters\))