Compute the moments for the AoI density function for a cohort of age a
momentAoI.RdCompute the moments for the AoI density function for a cohort of age a
Value
a numeric vector of length(a)
momentAoI.RdCompute the moments for the AoI density function for a cohort of age a
a numeric vector of length(a)