Compute the moments for the AoY density function for a cohort of age a
momentAoY.RdCompute the moments for the AoY density function for a cohort of age a
Value
a numeric vector of length(a)
momentAoY.RdCompute the moments for the AoY density function for a cohort of age a
a numeric vector of length(a)