The density function for parasite densities as a function of the mean
p_Omega.RdThe density function for parasite densities as a function of the mean
Usage
p_Omega(xi, mu, bvm = 13, par_Omega = par_Omega_beta())Value
a numeric vector of length(xi)
p_Omega.RdThe density function for parasite densities as a function of the mean
p_Omega(xi, mu, bvm = 13, par_Omega = par_Omega_beta())a numeric vector of length(xi)