A function to compute the variance of the beta distrution as a function of the mean.
sigma_mu.RdA function to compute the variance of the beta distrution as a function of the mean.
Value
a numeric vector of length(mu)
sigma_mu.RdA function to compute the variance of the beta distrution as a function of the mean.
a numeric vector of length(mu)