A function that returns constrained values of the variance for the beta distrution as a function of the mean.
sigma_mu.abc.RdA function that returns constrained values of the variance for the beta distrution as a function of the mean.
Usage
# S3 method for class 'abc'
sigma_mu(mu, par)Value
a numeric vector of length(mu)