Solve the system of differential equations to compute the approximate moments of the AoY over time.
solve_dAoYda.RdSolve the system of differential equations to compute the approximate moments of the AoY over time.
Value
a data.frame describing the orbits