Derivatives for SquIP
dSquIP.RdThis function computes the derivatives for the queuing model SquIP, in a form that can be used by deSolve::ode.
It also computes the derivatives for the hybrid variables \(m_1\) and \(m_2\)
Value
the derivatives as a list