Derivatives for SquIP
dSquIPz.RdThis computes the derivatives for the queuing model SquIP. It also computes the hybrid variables \(I, m_1\) and \(m_2\)
Value
the derivatives as a list
See also
This function computes the derivatives in a form that can be used by deSolve::ode.