Compute infection density in a cohort of humans, \(z_\bday(\alpha, a |h)\)
zda.RdGiven a function describing the FoI (\(h(a,d)\)), and a parameter describing the clearance rate of infections (\(r\)), the density of parasite clones of age \(\alpha\) distributed among a cohort of humans of age \(a\) is $$z_d(\alpha, a) = e^{-r \alpha} h(a-\alpha, d)$$
Value
a numeric vector of length(alpha)